<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

// Azure AD Authentication Routes
Route::get('/', [App\Http\Controllers\AuthController::class, 'signin'])->name('signin');
Route::get('/callback', [App\Http\Controllers\AuthController::class, 'callback'])->name('callback');
Route::get('/signout', [App\Http\Controllers\AuthController::class, 'signout'])->name('signout');

// Routes principales
Route::prefix('/')->middleware("CheckToken")->group(function () {
    Route::get('main', function () {
        return view('dashboard');
    })->name('dashboard');
    Route::get('employees', function () {
        return view('membersIcc');
    })->name('membres');
    Route::get('agences', function () {
        return view('agencesIcc');
    })->name('agences');
    Route::get('trainings', function () {
        return view('trainings');
    })->name('trainings');
    Route::get('devices', function () {
        return view('devicesIcc');
    })->name('devices');
    Route::get('/admin', function () {
        return view('adminIcc');
    })->name('admin');
});

// Users / Members
Route::prefix('employees')->middleware("CheckToken")->group(function () {
    Route::prefix('/actions')->group(function () {
        Route::post('/create', [App\Http\Controllers\Users\AddUserController::class, 'addUser'])->name('create_employee');
        Route::post('/update', [App\Http\Controllers\Users\UpdateUserController::class, 'updateUser'])->name('update_employee');
        Route::post('/orias', [App\Http\Controllers\Users\OriasController::class, 'addUpdateOrias'])->name('add_update_orias');
        Route::post('/ieam', [App\Http\Controllers\Users\IeamController::class, 'addUpdateIeam'])->name('add_update_ieam');
        Route::post('/afib', [App\Http\Controllers\Users\AfibController::class, 'addUpdateAfib'])->name('add_update_afib');
    });
    Route::prefix('/emails')->group(function () {
        Route::get('/user-credentials-email', [App\Http\Controllers\Emails\UserCredentialsEmailController::class, 'userCredentials'])->name('user_credentials_email');
        Route::get('/just-created-user-credentials-email', [App\Http\Controllers\Emails\JustCreatedUserCredentialsEmailController::class, 'justCreatedUserCredentials'])->name('just_created_user_credentials_email');
    });
});

// Agences
Route::prefix('agences')->middleware("CheckToken")->group(function () {
    Route::prefix('/actions')->group(function () {
        Route::post('/create', [App\Http\Controllers\Agences\AddAgenceController::class, 'addAgence'])->name('create_agence');
        Route::post('/update', [App\Http\Controllers\Agences\UpdateAgenceController::class, 'updateAgence'])->name('update_agence');
    });
});

// Trainings
Route::prefix('trainings')->middleware("CheckToken")->group(function () {
    Route::prefix('/actions')->group(function () {
        Route::post('/import', [App\Http\Controllers\Trainings\ImportSuiviFormationController::class, 'import'])->name('import_suivi');
    });
});

// Devices
Route::prefix('devices')->middleware("CheckToken")->group(function () {
    Route::prefix('actions')->group(function () {
        Route::post('/import', [App\Http\Controllers\Trainings\ImportSuiviFormationController::class, 'import'])->name('import_suivi');
    });
});

// Admin
Route::prefix('admin')->middleware("CheckToken")->group(function () {
    Route::prefix('actions')->group(function () {
        Route::get('/devices/sync', [App\Http\Controllers\Admin\Devices\SyncDevicesFromAzureAdtoDbController::class, 'syncDevicesInfo'])->name('sync_devices');
        Route::get('/employees/update-aad-id', [App\Http\Controllers\Admin\Employees\UpdateEmployeesAzureIdController::class, 'updateEmployeesIdAzure'])->name('update_idaad');
        Route::get('/employees/update-photos', [App\Http\Controllers\Admin\Employees\UpdateEmployeesPhotosController::class, 'updateEmployeesPhotos'])->name('update_photos');
        Route::get('/employees/update-enabled-status', [App\Http\Controllers\Admin\Employees\UpdateEmployeesEnabledStatusController::class, 'updateEmployeesEnabledStatus'])->name('update_enabled');
        Route::get('/employees/sync-users-aad-db', [App\Http\Controllers\Admin\Employees\SyncAllUsersFromAzureAdController::class, 'syncAllUsers'])->name('sync_users_aad_db');
    });
});

// A garder pour le moment : Route::get('/update-producteurs', [App\Http\Controllers\AddUpdateProducteursController::class, 'updateProducteurs'])->name('update_producteurs');